# 🗂 forg
Simple Folder organization in python. Based on Kalle Hallden snippet

## How It Works
Go to the folder you want to organize, and in comand line, exxecute:
 ```sh
   forg
   ```
 It creates a folder called forg on the folder from where you called the command , and based in a list of file extension, it creates subfolders in forg and move files there categorizing them by type.


## Folders

| Folder | File Extensions |
| ------ |:---------------:|
| application | ".abw",".arc",".bin",".bz",".bz2",".csh",".dmg",".eot",".epub",".gz",".jar",".js",".json",".jsonld",".cda",".mpkg",".ogx",".ogg",".php",".rar",".sh",".swf",".tar",".vsd",".xhtml",".xls",".xlsx",".xml",".xul",".zip",".7z",".pkg",".pem",".pkpass" |
| audio | ".aac",".mid",".midi",".mp3",".m4a",".oga",".ogg",".opus",".wav",".weba",".wma",".m3u8" |
| books | ".epub" ,".mobi",".azw3",".djvu", ".azw", ".azw3", ".kf8", ".kfx", ".ibooks", ".cbr", ".cbz"," .cb7", ".cbt", ".cba" |
| documents | ".doc",".docx",".htm",".html",".ics",".odp",".ods",".odt",".pdf",".ppt",".pptx",".rtf",".txt",".ppsx",".notesairdropdocument",".xlsm",".torrent",".srt",".css",".csv",".mjs",".key",".pages" |
| fonts | ".otf",".ttf",".woff",".woff2" |
| image | ".bmp",".gif",".ico",".jpeg",".jpg",".JPG",".png",".svg",".tif",".tiff",".webp",".png",".dwg",".ai",".cdr",".psd" |
| video  | ".avi",".mp4",".mpeg",".m4v",".mov",".ogv",".ts",".webm",".3gp",".3g2",".wmv",".mkv" |